#![feature(test)]
#![allow(bad_style)]

extern crate test;
use test::Bencher;

use randomize::*;

#[bench]
fn bench_fill_bytes_PCG32(b: &mut Bencher) {
  let mut v = vec![0u8; 1_000_000];
  let mut gen = PCG32::seed(clock_u64(), 5);
  b.iter(|| {
    gen.fill_bytes(&mut v[..]);
  });
  println!("{}", v[0]);
}

#[bench]
fn bench_fill_bytes_PCG64(b: &mut Bencher) {
  let mut v = vec![0u8; 1_000_000];
  let mut gen = PCG64::seed(u128::from(clock_u64()), 5);
  b.iter(|| {
    gen.fill_bytes(&mut v[..]);
  });
  println!("{}", v[0]);
}

#[bench]
fn bench_fill_bytes_AnyPCG32(b: &mut Bencher) {
  let mut v = vec![0u8; 1_000_000];
  let mut gen = AnyPCG::new(PCG32::seed(clock_u64(), 5));
  b.iter(|| {
    gen.fill_bytes(&mut v[..]);
  });
  println!("{}", v[0]);
}

#[bench]
fn bench_fill_bytes_AnyPCG64(b: &mut Bencher) {
  let mut v = vec![0u8; 1_000_000];
  let mut gen = AnyPCG::new(PCG64::seed(u128::from(clock_u64()), 5));
  b.iter(|| {
    gen.fill_bytes(&mut v[..]);
  });
  println!("{}", v[0]);
}

/// A `u64` based on the system clock.
fn clock_u64() -> u64 {
  let now = std::time::SystemTime::now();
  match now.duration_since(std::time::SystemTime::UNIX_EPOCH) {
    Ok(dur) => dur.as_secs(),
    Err(ste) => ste.duration().as_secs(),
  }
}
